Struct code_minimap::lossy_reader::LossyReader [−][src]
pub struct LossyReader<R> { /* fields omitted */ }Implementations
impl<R: Read> LossyReader<R>[src]
impl<R: Read> LossyReader<R>[src]Trait Implementations
impl<R: Read> BufRead for LossyReader<R>[src]
impl<R: Read> BufRead for LossyReader<R>[src]fn fill_buf(&mut self) -> Result<&[u8]>[src]
fn fill_buf(&mut self) -> Result<&[u8]>[src]Returns the contents of the internal buffer, filling it with more data from the inner reader if it is empty. Read more
fn consume(&mut self, amt: usize)[src]
fn consume(&mut self, amt: usize)[src]Tells this buffer that amt bytes have been consumed from the buffer,
so they should no longer be returned in calls to read. Read more
fn read_line(&mut self, buf: &mut String) -> Result<usize>[src]
fn read_line(&mut self, buf: &mut String) -> Result<usize>[src]Read all bytes until a newline (the 0xA byte) is reached, and append
them to the provided buffer. Read more
fn read_until(
&mut self,
byte: u8,
buf: &mut Vec<u8, Global>
) -> Result<usize, Error>1.0.0[src]
fn read_until(
&mut self,
byte: u8,
buf: &mut Vec<u8, Global>
) -> Result<usize, Error>1.0.0[src]Read all bytes into buf until the delimiter byte or EOF is reached. Read more
impl<R: Read> Read for LossyReader<R>[src]
impl<R: Read> Read for LossyReader<R>[src]fn read(&mut self, buf: &mut [u8]) -> Result<usize>[src]
fn read(&mut self, buf: &mut [u8]) -> Result<usize>[src]Pull some bytes from this source into the specified buffer, returning how many bytes were read. Read more
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>1.36.0[src]
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>1.36.0[src]Like read, except that it reads into a slice of buffers. Read more
fn is_read_vectored(&self) -> bool[src]
fn is_read_vectored(&self) -> bool[src]can_vector)Determines if this Reader has an efficient read_vectored
implementation. Read more
unsafe fn initializer(&self) -> Initializer[src]
unsafe fn initializer(&self) -> Initializer[src]read_initializer)Determines if this Reader can work with buffers of uninitialized
memory. Read more
fn read_to_end(&mut self, buf: &mut Vec<u8, Global>) -> Result<usize, Error>1.0.0[src]
fn read_to_end(&mut self, buf: &mut Vec<u8, Global>) -> Result<usize, Error>1.0.0[src]Read all bytes until EOF in this source, placing them into buf. Read more
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>1.0.0[src]
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>1.0.0[src]Read all bytes until EOF in this source, appending them to buf. Read more
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>1.6.0[src]
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>1.6.0[src]Read the exact number of bytes required to fill buf. Read more
fn by_ref(&mut self) -> &mut Self1.0.0[src]
fn by_ref(&mut self) -> &mut Self1.0.0[src]Creates a “by reference” adaptor for this instance of Read. Read more